#
#
#

[mypy]
python_version = 3.9
warn_return_any = True
warn_unused_configs = True
files=src/

[mypy-setuptools.*]
    ignore_missing_imports = True

{% for module_name in dependencies %}
[mypy-{{module_name}}.*]
    ignore_missing_imports = True
    
{% endfor %}
