cmake_minimum_required(VERSION 3.21)

add_{{ lib_or_exec }}({{ project_name|lower }}
    {{ project_name|lower }}.hpp
    {{ project_name|lower }}.cpp
)

include_directories(${PROJECT_SOURCE_DIR}/src)
